---
name: Bug report
about: Bug reports help us improve!  Thanks for submitting yours!
title: "[BUG] "
labels: bug
assignees: ''

---

## Expected Behavior
Tell us what should happen

## Actual Behavior
Tell us what happens instead

## Example Code
Please see [How to create a Minimal, Reproducible example](https://stackoverflow.com/help/minimal-reproducible-example) for some guidance on creating the best possible example of the problem
```python

```

## Full Traceback
```pytb
Paste the full traceback in case there is an exception

```

## Your Environment
* Python version:
* graspologic version:

## Additional Details
Any other contextual information you might feel is important.
